/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CloudiotDeviceConfig extends cdktf.TerraformMetaArguments {
    /**
    * If a device is blocked, connections or requests from this device will fail.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#blocked CloudiotDevice#blocked}
    */
    readonly blocked?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#id CloudiotDevice#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The logging verbosity for device activity. Possible values: ["NONE", "ERROR", "INFO", "DEBUG"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#log_level CloudiotDevice#log_level}
    */
    readonly logLevel?: string;
    /**
    * The metadata key-value pairs assigned to the device.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#metadata CloudiotDevice#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * A unique name for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#name CloudiotDevice#name}
    */
    readonly name: string;
    /**
    * The name of the device registry where this device should be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#registry CloudiotDevice#registry}
    */
    readonly registry: string;
    /**
    * credentials block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#credentials CloudiotDevice#credentials}
    */
    readonly credentials?: CloudiotDeviceCredentials[] | cdktf.IResolvable;
    /**
    * gateway_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#gateway_config CloudiotDevice#gateway_config}
    */
    readonly gatewayConfig?: CloudiotDeviceGatewayConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#timeouts CloudiotDevice#timeouts}
    */
    readonly timeouts?: CloudiotDeviceTimeouts;
}
export interface CloudiotDeviceConfigA {
}
export declare function cloudiotDeviceConfigAToTerraform(struct?: CloudiotDeviceConfigA): any;
export declare class CloudiotDeviceConfigAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CloudiotDeviceConfigA | undefined;
    set internalValue(value: CloudiotDeviceConfigA | undefined);
    get binaryData(): string;
    get cloudUpdateTime(): string;
    get deviceAckTime(): string;
    get version(): string;
}
export declare class CloudiotDeviceConfigAList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CloudiotDeviceConfigAOutputReference;
}
export interface CloudiotDeviceLastErrorStatus {
}
export declare function cloudiotDeviceLastErrorStatusToTerraform(struct?: CloudiotDeviceLastErrorStatus): any;
export declare class CloudiotDeviceLastErrorStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CloudiotDeviceLastErrorStatus | undefined;
    set internalValue(value: CloudiotDeviceLastErrorStatus | undefined);
    private _details;
    get details(): cdktf.StringMapList;
    get message(): string;
    get number(): number;
}
export declare class CloudiotDeviceLastErrorStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CloudiotDeviceLastErrorStatusOutputReference;
}
export interface CloudiotDeviceState {
}
export declare function cloudiotDeviceStateToTerraform(struct?: CloudiotDeviceState): any;
export declare class CloudiotDeviceStateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CloudiotDeviceState | undefined;
    set internalValue(value: CloudiotDeviceState | undefined);
    get binaryData(): string;
    get updateTime(): string;
}
export declare class CloudiotDeviceStateList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CloudiotDeviceStateOutputReference;
}
export interface CloudiotDeviceCredentialsPublicKey {
    /**
    * The format of the key. Possible values: ["RSA_PEM", "RSA_X509_PEM", "ES256_PEM", "ES256_X509_PEM"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#format CloudiotDevice#format}
    */
    readonly format: string;
    /**
    * The key data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#key CloudiotDevice#key}
    */
    readonly key: string;
}
export declare function cloudiotDeviceCredentialsPublicKeyToTerraform(struct?: CloudiotDeviceCredentialsPublicKeyOutputReference | CloudiotDeviceCredentialsPublicKey): any;
export declare class CloudiotDeviceCredentialsPublicKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CloudiotDeviceCredentialsPublicKey | undefined;
    set internalValue(value: CloudiotDeviceCredentialsPublicKey | undefined);
    private _format?;
    get format(): string;
    set format(value: string);
    get formatInput(): string | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
}
export interface CloudiotDeviceCredentials {
    /**
    * The time at which this credential becomes invalid.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#expiration_time CloudiotDevice#expiration_time}
    */
    readonly expirationTime?: string;
    /**
    * public_key block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#public_key CloudiotDevice#public_key}
    */
    readonly publicKey: CloudiotDeviceCredentialsPublicKey;
}
export declare function cloudiotDeviceCredentialsToTerraform(struct?: CloudiotDeviceCredentials | cdktf.IResolvable): any;
export declare class CloudiotDeviceCredentialsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CloudiotDeviceCredentials | cdktf.IResolvable | undefined;
    set internalValue(value: CloudiotDeviceCredentials | cdktf.IResolvable | undefined);
    private _expirationTime?;
    get expirationTime(): string;
    set expirationTime(value: string);
    resetExpirationTime(): void;
    get expirationTimeInput(): string | undefined;
    private _publicKey;
    get publicKey(): CloudiotDeviceCredentialsPublicKeyOutputReference;
    putPublicKey(value: CloudiotDeviceCredentialsPublicKey): void;
    get publicKeyInput(): CloudiotDeviceCredentialsPublicKey | undefined;
}
export declare class CloudiotDeviceCredentialsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CloudiotDeviceCredentials[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CloudiotDeviceCredentialsOutputReference;
}
export interface CloudiotDeviceGatewayConfig {
    /**
    * Indicates whether the device is a gateway. Possible values: ["ASSOCIATION_ONLY", "DEVICE_AUTH_TOKEN_ONLY", "ASSOCIATION_AND_DEVICE_AUTH_TOKEN"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#gateway_auth_method CloudiotDevice#gateway_auth_method}
    */
    readonly gatewayAuthMethod?: string;
    /**
    * Indicates whether the device is a gateway. Default value: "NON_GATEWAY" Possible values: ["GATEWAY", "NON_GATEWAY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#gateway_type CloudiotDevice#gateway_type}
    */
    readonly gatewayType?: string;
}
export declare function cloudiotDeviceGatewayConfigToTerraform(struct?: CloudiotDeviceGatewayConfigOutputReference | CloudiotDeviceGatewayConfig): any;
export declare class CloudiotDeviceGatewayConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CloudiotDeviceGatewayConfig | undefined;
    set internalValue(value: CloudiotDeviceGatewayConfig | undefined);
    private _gatewayAuthMethod?;
    get gatewayAuthMethod(): string;
    set gatewayAuthMethod(value: string);
    resetGatewayAuthMethod(): void;
    get gatewayAuthMethodInput(): string | undefined;
    private _gatewayType?;
    get gatewayType(): string;
    set gatewayType(value: string);
    resetGatewayType(): void;
    get gatewayTypeInput(): string | undefined;
    get lastAccessedGatewayId(): string;
    get lastAccessedGatewayTime(): string;
}
export interface CloudiotDeviceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#create CloudiotDevice#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#delete CloudiotDevice#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device#update CloudiotDevice#update}
    */
    readonly update?: string;
}
export declare function cloudiotDeviceTimeoutsToTerraform(struct?: CloudiotDeviceTimeouts | cdktf.IResolvable): any;
export declare class CloudiotDeviceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CloudiotDeviceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: CloudiotDeviceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device google_cloudiot_device}
*/
export declare class CloudiotDevice extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_cloudiot_device";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/cloudiot_device google_cloudiot_device} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CloudiotDeviceConfig
    */
    constructor(scope: Construct, id: string, config: CloudiotDeviceConfig);
    private _blocked?;
    get blocked(): boolean | cdktf.IResolvable;
    set blocked(value: boolean | cdktf.IResolvable);
    resetBlocked(): void;
    get blockedInput(): boolean | cdktf.IResolvable | undefined;
    private _config;
    get config(): CloudiotDeviceConfigAList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastConfigAckTime(): string;
    get lastConfigSendTime(): string;
    private _lastErrorStatus;
    get lastErrorStatus(): CloudiotDeviceLastErrorStatusList;
    get lastErrorTime(): string;
    get lastEventTime(): string;
    get lastHeartbeatTime(): string;
    get lastStateTime(): string;
    private _logLevel?;
    get logLevel(): string;
    set logLevel(value: string);
    resetLogLevel(): void;
    get logLevelInput(): string | undefined;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get numId(): string;
    private _registry?;
    get registry(): string;
    set registry(value: string);
    get registryInput(): string | undefined;
    private _state;
    get state(): CloudiotDeviceStateList;
    private _credentials;
    get credentials(): CloudiotDeviceCredentialsList;
    putCredentials(value: CloudiotDeviceCredentials[] | cdktf.IResolvable): void;
    resetCredentials(): void;
    get credentialsInput(): cdktf.IResolvable | CloudiotDeviceCredentials[] | undefined;
    private _gatewayConfig;
    get gatewayConfig(): CloudiotDeviceGatewayConfigOutputReference;
    putGatewayConfig(value: CloudiotDeviceGatewayConfig): void;
    resetGatewayConfig(): void;
    get gatewayConfigInput(): CloudiotDeviceGatewayConfig | undefined;
    private _timeouts;
    get timeouts(): CloudiotDeviceTimeoutsOutputReference;
    putTimeouts(value: CloudiotDeviceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | CloudiotDeviceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
