/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataplexDatascanConfig extends cdktf.TerraformMetaArguments {
    /**
    * DataScan identifier. Must contain only lowercase letters, numbers and hyphens. Must start with a letter. Must end with a number or a letter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#data_scan_id DataplexDatascan#data_scan_id}
    */
    readonly dataScanId: string;
    /**
    * Description of the scan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#description DataplexDatascan#description}
    */
    readonly description?: string;
    /**
    * User friendly display name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#display_name DataplexDatascan#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#id DataplexDatascan#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User-defined labels for the scan. A list of key->value pairs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#labels DataplexDatascan#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location where the data scan should reside.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#location DataplexDatascan#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#project DataplexDatascan#project}
    */
    readonly project?: string;
    /**
    * data block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#data DataplexDatascan#data}
    */
    readonly data: DataplexDatascanData;
    /**
    * data_profile_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#data_profile_spec DataplexDatascan#data_profile_spec}
    */
    readonly dataProfileSpec?: DataplexDatascanDataProfileSpec;
    /**
    * data_quality_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#data_quality_spec DataplexDatascan#data_quality_spec}
    */
    readonly dataQualitySpec?: DataplexDatascanDataQualitySpec;
    /**
    * execution_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#execution_spec DataplexDatascan#execution_spec}
    */
    readonly executionSpec: DataplexDatascanExecutionSpec;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#timeouts DataplexDatascan#timeouts}
    */
    readonly timeouts?: DataplexDatascanTimeouts;
}
export interface DataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfile {
}
export declare function dataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileToTerraform(struct?: DataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfile): any;
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfile | undefined;
    set internalValue(value: DataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfile | undefined);
    get average(): number;
    get max(): string;
    get min(): string;
    get quartiles(): string;
    get standardDeviation(): number;
}
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileOutputReference;
}
export interface DataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfile {
}
export declare function dataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileToTerraform(struct?: DataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfile): any;
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfile | undefined;
    set internalValue(value: DataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfile | undefined);
    get average(): number;
    get max(): string;
    get min(): string;
    get quartiles(): string;
    get standardDeviation(): number;
}
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileOutputReference;
}
export interface DataplexDatascanDataProfileResultProfileFieldsProfileStringProfile {
}
export declare function dataplexDatascanDataProfileResultProfileFieldsProfileStringProfileToTerraform(struct?: DataplexDatascanDataProfileResultProfileFieldsProfileStringProfile): any;
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileStringProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResultProfileFieldsProfileStringProfile | undefined;
    set internalValue(value: DataplexDatascanDataProfileResultProfileFieldsProfileStringProfile | undefined);
    get averageLength(): number;
    get maxLength(): string;
    get minLength(): string;
}
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileStringProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultProfileFieldsProfileStringProfileOutputReference;
}
export interface DataplexDatascanDataProfileResultProfileFieldsProfileTopNValues {
}
export declare function dataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesToTerraform(struct?: DataplexDatascanDataProfileResultProfileFieldsProfileTopNValues): any;
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResultProfileFieldsProfileTopNValues | undefined;
    set internalValue(value: DataplexDatascanDataProfileResultProfileFieldsProfileTopNValues | undefined);
    get count(): string;
    get value(): string;
}
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesOutputReference;
}
export interface DataplexDatascanDataProfileResultProfileFieldsProfile {
}
export declare function dataplexDatascanDataProfileResultProfileFieldsProfileToTerraform(struct?: DataplexDatascanDataProfileResultProfileFieldsProfile): any;
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResultProfileFieldsProfile | undefined;
    set internalValue(value: DataplexDatascanDataProfileResultProfileFieldsProfile | undefined);
    get distinctRatio(): number;
    private _doubleProfile;
    get doubleProfile(): DataplexDatascanDataProfileResultProfileFieldsProfileDoubleProfileList;
    private _integerProfile;
    get integerProfile(): DataplexDatascanDataProfileResultProfileFieldsProfileIntegerProfileList;
    get nullRatio(): number;
    private _stringProfile;
    get stringProfile(): DataplexDatascanDataProfileResultProfileFieldsProfileStringProfileList;
    private _topNValues;
    get topNValues(): DataplexDatascanDataProfileResultProfileFieldsProfileTopNValuesList;
}
export declare class DataplexDatascanDataProfileResultProfileFieldsProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultProfileFieldsProfileOutputReference;
}
export interface DataplexDatascanDataProfileResultProfileFields {
}
export declare function dataplexDatascanDataProfileResultProfileFieldsToTerraform(struct?: DataplexDatascanDataProfileResultProfileFields): any;
export declare class DataplexDatascanDataProfileResultProfileFieldsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResultProfileFields | undefined;
    set internalValue(value: DataplexDatascanDataProfileResultProfileFields | undefined);
    get mode(): string;
    get name(): string;
    private _profile;
    get profile(): DataplexDatascanDataProfileResultProfileFieldsProfileList;
    get type(): string;
}
export declare class DataplexDatascanDataProfileResultProfileFieldsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultProfileFieldsOutputReference;
}
export interface DataplexDatascanDataProfileResultProfile {
}
export declare function dataplexDatascanDataProfileResultProfileToTerraform(struct?: DataplexDatascanDataProfileResultProfile): any;
export declare class DataplexDatascanDataProfileResultProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResultProfile | undefined;
    set internalValue(value: DataplexDatascanDataProfileResultProfile | undefined);
    private _fields;
    get fields(): DataplexDatascanDataProfileResultProfileFieldsList;
}
export declare class DataplexDatascanDataProfileResultProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultProfileOutputReference;
}
export interface DataplexDatascanDataProfileResultScannedDataIncrementalField {
}
export declare function dataplexDatascanDataProfileResultScannedDataIncrementalFieldToTerraform(struct?: DataplexDatascanDataProfileResultScannedDataIncrementalField): any;
export declare class DataplexDatascanDataProfileResultScannedDataIncrementalFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResultScannedDataIncrementalField | undefined;
    set internalValue(value: DataplexDatascanDataProfileResultScannedDataIncrementalField | undefined);
    get end(): string;
    get field(): string;
    get start(): string;
}
export declare class DataplexDatascanDataProfileResultScannedDataIncrementalFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultScannedDataIncrementalFieldOutputReference;
}
export interface DataplexDatascanDataProfileResultScannedData {
}
export declare function dataplexDatascanDataProfileResultScannedDataToTerraform(struct?: DataplexDatascanDataProfileResultScannedData): any;
export declare class DataplexDatascanDataProfileResultScannedDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResultScannedData | undefined;
    set internalValue(value: DataplexDatascanDataProfileResultScannedData | undefined);
    private _incrementalField;
    get incrementalField(): DataplexDatascanDataProfileResultScannedDataIncrementalFieldList;
}
export declare class DataplexDatascanDataProfileResultScannedDataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultScannedDataOutputReference;
}
export interface DataplexDatascanDataProfileResult {
}
export declare function dataplexDatascanDataProfileResultToTerraform(struct?: DataplexDatascanDataProfileResult): any;
export declare class DataplexDatascanDataProfileResultOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataProfileResult | undefined;
    set internalValue(value: DataplexDatascanDataProfileResult | undefined);
    private _profile;
    get profile(): DataplexDatascanDataProfileResultProfileList;
    get rowCount(): string;
    private _scannedData;
    get scannedData(): DataplexDatascanDataProfileResultScannedDataList;
}
export declare class DataplexDatascanDataProfileResultList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataProfileResultOutputReference;
}
export interface DataplexDatascanDataQualityResultDimensions {
}
export declare function dataplexDatascanDataQualityResultDimensionsToTerraform(struct?: DataplexDatascanDataQualityResultDimensions): any;
export declare class DataplexDatascanDataQualityResultDimensionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultDimensions | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultDimensions | undefined);
    get passed(): cdktf.IResolvable;
}
export declare class DataplexDatascanDataQualityResultDimensionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultDimensionsOutputReference;
}
export interface DataplexDatascanDataQualityResultRulesRuleNonNullExpectation {
}
export declare function dataplexDatascanDataQualityResultRulesRuleNonNullExpectationToTerraform(struct?: DataplexDatascanDataQualityResultRulesRuleNonNullExpectation): any;
export declare class DataplexDatascanDataQualityResultRulesRuleNonNullExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRulesRuleNonNullExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRulesRuleNonNullExpectation | undefined);
}
export declare class DataplexDatascanDataQualityResultRulesRuleNonNullExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesRuleNonNullExpectationOutputReference;
}
export interface DataplexDatascanDataQualityResultRulesRuleRangeExpectation {
}
export declare function dataplexDatascanDataQualityResultRulesRuleRangeExpectationToTerraform(struct?: DataplexDatascanDataQualityResultRulesRuleRangeExpectation): any;
export declare class DataplexDatascanDataQualityResultRulesRuleRangeExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRulesRuleRangeExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRulesRuleRangeExpectation | undefined);
    get maxValue(): string;
    get minValue(): string;
    get strictMaxEnabled(): cdktf.IResolvable;
    get strictMinEnabled(): cdktf.IResolvable;
}
export declare class DataplexDatascanDataQualityResultRulesRuleRangeExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesRuleRangeExpectationOutputReference;
}
export interface DataplexDatascanDataQualityResultRulesRuleRegexExpectation {
}
export declare function dataplexDatascanDataQualityResultRulesRuleRegexExpectationToTerraform(struct?: DataplexDatascanDataQualityResultRulesRuleRegexExpectation): any;
export declare class DataplexDatascanDataQualityResultRulesRuleRegexExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRulesRuleRegexExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRulesRuleRegexExpectation | undefined);
    get regex(): string;
}
export declare class DataplexDatascanDataQualityResultRulesRuleRegexExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesRuleRegexExpectationOutputReference;
}
export interface DataplexDatascanDataQualityResultRulesRuleRowConditionExpectation {
}
export declare function dataplexDatascanDataQualityResultRulesRuleRowConditionExpectationToTerraform(struct?: DataplexDatascanDataQualityResultRulesRuleRowConditionExpectation): any;
export declare class DataplexDatascanDataQualityResultRulesRuleRowConditionExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRulesRuleRowConditionExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRulesRuleRowConditionExpectation | undefined);
    get sqlExpression(): string;
}
export declare class DataplexDatascanDataQualityResultRulesRuleRowConditionExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesRuleRowConditionExpectationOutputReference;
}
export interface DataplexDatascanDataQualityResultRulesRuleSetExpectation {
}
export declare function dataplexDatascanDataQualityResultRulesRuleSetExpectationToTerraform(struct?: DataplexDatascanDataQualityResultRulesRuleSetExpectation): any;
export declare class DataplexDatascanDataQualityResultRulesRuleSetExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRulesRuleSetExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRulesRuleSetExpectation | undefined);
    get values(): string[];
}
export declare class DataplexDatascanDataQualityResultRulesRuleSetExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesRuleSetExpectationOutputReference;
}
export interface DataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectation {
}
export declare function dataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationToTerraform(struct?: DataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectation): any;
export declare class DataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectation | undefined);
    get maxValue(): string;
    get minValue(): string;
    get statistic(): string;
    get strictMaxEnabled(): cdktf.IResolvable;
    get strictMinEnabled(): cdktf.IResolvable;
}
export declare class DataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationOutputReference;
}
export interface DataplexDatascanDataQualityResultRulesRuleTableConditionExpectation {
}
export declare function dataplexDatascanDataQualityResultRulesRuleTableConditionExpectationToTerraform(struct?: DataplexDatascanDataQualityResultRulesRuleTableConditionExpectation): any;
export declare class DataplexDatascanDataQualityResultRulesRuleTableConditionExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRulesRuleTableConditionExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRulesRuleTableConditionExpectation | undefined);
    get sqlExpression(): string;
}
export declare class DataplexDatascanDataQualityResultRulesRuleTableConditionExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesRuleTableConditionExpectationOutputReference;
}
export interface DataplexDatascanDataQualityResultRulesRuleUniquenessExpectation {
}
export declare function dataplexDatascanDataQualityResultRulesRuleUniquenessExpectationToTerraform(struct?: DataplexDatascanDataQualityResultRulesRuleUniquenessExpectation): any;
export declare class DataplexDatascanDataQualityResultRulesRuleUniquenessExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRulesRuleUniquenessExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRulesRuleUniquenessExpectation | undefined);
}
export declare class DataplexDatascanDataQualityResultRulesRuleUniquenessExpectationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesRuleUniquenessExpectationOutputReference;
}
export interface DataplexDatascanDataQualityResultRulesRule {
}
export declare function dataplexDatascanDataQualityResultRulesRuleToTerraform(struct?: DataplexDatascanDataQualityResultRulesRule): any;
export declare class DataplexDatascanDataQualityResultRulesRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRulesRule | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRulesRule | undefined);
    get column(): string;
    get dimension(): string;
    get ignoreNull(): cdktf.IResolvable;
    private _nonNullExpectation;
    get nonNullExpectation(): DataplexDatascanDataQualityResultRulesRuleNonNullExpectationList;
    private _rangeExpectation;
    get rangeExpectation(): DataplexDatascanDataQualityResultRulesRuleRangeExpectationList;
    private _regexExpectation;
    get regexExpectation(): DataplexDatascanDataQualityResultRulesRuleRegexExpectationList;
    private _rowConditionExpectation;
    get rowConditionExpectation(): DataplexDatascanDataQualityResultRulesRuleRowConditionExpectationList;
    private _setExpectation;
    get setExpectation(): DataplexDatascanDataQualityResultRulesRuleSetExpectationList;
    private _statisticRangeExpectation;
    get statisticRangeExpectation(): DataplexDatascanDataQualityResultRulesRuleStatisticRangeExpectationList;
    private _tableConditionExpectation;
    get tableConditionExpectation(): DataplexDatascanDataQualityResultRulesRuleTableConditionExpectationList;
    get threshold(): number;
    private _uniquenessExpectation;
    get uniquenessExpectation(): DataplexDatascanDataQualityResultRulesRuleUniquenessExpectationList;
}
export declare class DataplexDatascanDataQualityResultRulesRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesRuleOutputReference;
}
export interface DataplexDatascanDataQualityResultRules {
}
export declare function dataplexDatascanDataQualityResultRulesToTerraform(struct?: DataplexDatascanDataQualityResultRules): any;
export declare class DataplexDatascanDataQualityResultRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultRules | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultRules | undefined);
    get evaluatedCount(): string;
    get failingRowsQuery(): string;
    get nullCount(): string;
    get passRatio(): number;
    get passed(): cdktf.IResolvable;
    get passedCount(): string;
    private _rule;
    get rule(): DataplexDatascanDataQualityResultRulesRuleList;
}
export declare class DataplexDatascanDataQualityResultRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultRulesOutputReference;
}
export interface DataplexDatascanDataQualityResultScannedDataIncrementalField {
}
export declare function dataplexDatascanDataQualityResultScannedDataIncrementalFieldToTerraform(struct?: DataplexDatascanDataQualityResultScannedDataIncrementalField): any;
export declare class DataplexDatascanDataQualityResultScannedDataIncrementalFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultScannedDataIncrementalField | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultScannedDataIncrementalField | undefined);
    get end(): string;
    get field(): string;
    get start(): string;
}
export declare class DataplexDatascanDataQualityResultScannedDataIncrementalFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultScannedDataIncrementalFieldOutputReference;
}
export interface DataplexDatascanDataQualityResultScannedData {
}
export declare function dataplexDatascanDataQualityResultScannedDataToTerraform(struct?: DataplexDatascanDataQualityResultScannedData): any;
export declare class DataplexDatascanDataQualityResultScannedDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResultScannedData | undefined;
    set internalValue(value: DataplexDatascanDataQualityResultScannedData | undefined);
    private _incrementalField;
    get incrementalField(): DataplexDatascanDataQualityResultScannedDataIncrementalFieldList;
}
export declare class DataplexDatascanDataQualityResultScannedDataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultScannedDataOutputReference;
}
export interface DataplexDatascanDataQualityResult {
}
export declare function dataplexDatascanDataQualityResultToTerraform(struct?: DataplexDatascanDataQualityResult): any;
export declare class DataplexDatascanDataQualityResultOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualityResult | undefined;
    set internalValue(value: DataplexDatascanDataQualityResult | undefined);
    private _dimensions;
    get dimensions(): DataplexDatascanDataQualityResultDimensionsList;
    get passed(): cdktf.IResolvable;
    get rowCount(): string;
    private _rules;
    get rules(): DataplexDatascanDataQualityResultRulesList;
    private _scannedData;
    get scannedData(): DataplexDatascanDataQualityResultScannedDataList;
}
export declare class DataplexDatascanDataQualityResultList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualityResultOutputReference;
}
export interface DataplexDatascanExecutionStatus {
}
export declare function dataplexDatascanExecutionStatusToTerraform(struct?: DataplexDatascanExecutionStatus): any;
export declare class DataplexDatascanExecutionStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanExecutionStatus | undefined;
    set internalValue(value: DataplexDatascanExecutionStatus | undefined);
    get latestJobEndTime(): string;
    get latestJobStartTime(): string;
}
export declare class DataplexDatascanExecutionStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanExecutionStatusOutputReference;
}
export interface DataplexDatascanData {
    /**
    * The Dataplex entity that represents the data source(e.g. BigQuery table) for Datascan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#entity DataplexDatascan#entity}
    */
    readonly entity?: string;
    /**
    * The service-qualified full resource name of the cloud resource for a DataScan job to scan against. The field could be:
  (Cloud Storage bucket for DataDiscoveryScan)BigQuery table of type "TABLE" for DataProfileScan/DataQualityScan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#resource DataplexDatascan#resource}
    */
    readonly resource?: string;
}
export declare function dataplexDatascanDataToTerraform(struct?: DataplexDatascanDataOutputReference | DataplexDatascanData): any;
export declare class DataplexDatascanDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanData | undefined;
    set internalValue(value: DataplexDatascanData | undefined);
    private _entity?;
    get entity(): string;
    set entity(value: string);
    resetEntity(): void;
    get entityInput(): string | undefined;
    private _resource?;
    get resource(): string;
    set resource(value: string);
    resetResource(): void;
    get resourceInput(): string | undefined;
}
export interface DataplexDatascanDataProfileSpec {
    /**
    * A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in BigQuery standard SQL syntax. Example: col1 >= 0 AND col2 < 10
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#row_filter DataplexDatascan#row_filter}
    */
    readonly rowFilter?: string;
    /**
    * The percentage of the records to be selected from the dataset for DataScan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#sampling_percent DataplexDatascan#sampling_percent}
    */
    readonly samplingPercent?: number;
}
export declare function dataplexDatascanDataProfileSpecToTerraform(struct?: DataplexDatascanDataProfileSpecOutputReference | DataplexDatascanDataProfileSpec): any;
export declare class DataplexDatascanDataProfileSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataProfileSpec | undefined;
    set internalValue(value: DataplexDatascanDataProfileSpec | undefined);
    private _rowFilter?;
    get rowFilter(): string;
    set rowFilter(value: string);
    resetRowFilter(): void;
    get rowFilterInput(): string | undefined;
    private _samplingPercent?;
    get samplingPercent(): number;
    set samplingPercent(value: number);
    resetSamplingPercent(): void;
    get samplingPercentInput(): number | undefined;
}
export interface DataplexDatascanDataQualitySpecRulesNonNullExpectation {
}
export declare function dataplexDatascanDataQualitySpecRulesNonNullExpectationToTerraform(struct?: DataplexDatascanDataQualitySpecRulesNonNullExpectationOutputReference | DataplexDatascanDataQualitySpecRulesNonNullExpectation): any;
export declare class DataplexDatascanDataQualitySpecRulesNonNullExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataQualitySpecRulesNonNullExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpecRulesNonNullExpectation | undefined);
}
export interface DataplexDatascanDataQualitySpecRulesRangeExpectation {
    /**
    * The maximum column value allowed for a row to pass this validation. At least one of minValue and maxValue need to be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#max_value DataplexDatascan#max_value}
    */
    readonly maxValue?: string;
    /**
    * The minimum column value allowed for a row to pass this validation. At least one of minValue and maxValue need to be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#min_value DataplexDatascan#min_value}
    */
    readonly minValue?: string;
    /**
    * Whether each value needs to be strictly lesser than ('<') the maximum, or if equality is allowed.
  Only relevant if a maxValue has been defined. Default = false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#strict_max_enabled DataplexDatascan#strict_max_enabled}
    */
    readonly strictMaxEnabled?: boolean | cdktf.IResolvable;
    /**
    * Whether each value needs to be strictly greater than ('>') the minimum, or if equality is allowed.
  Only relevant if a minValue has been defined. Default = false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#strict_min_enabled DataplexDatascan#strict_min_enabled}
    */
    readonly strictMinEnabled?: boolean | cdktf.IResolvable;
}
export declare function dataplexDatascanDataQualitySpecRulesRangeExpectationToTerraform(struct?: DataplexDatascanDataQualitySpecRulesRangeExpectationOutputReference | DataplexDatascanDataQualitySpecRulesRangeExpectation): any;
export declare class DataplexDatascanDataQualitySpecRulesRangeExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataQualitySpecRulesRangeExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpecRulesRangeExpectation | undefined);
    private _maxValue?;
    get maxValue(): string;
    set maxValue(value: string);
    resetMaxValue(): void;
    get maxValueInput(): string | undefined;
    private _minValue?;
    get minValue(): string;
    set minValue(value: string);
    resetMinValue(): void;
    get minValueInput(): string | undefined;
    private _strictMaxEnabled?;
    get strictMaxEnabled(): boolean | cdktf.IResolvable;
    set strictMaxEnabled(value: boolean | cdktf.IResolvable);
    resetStrictMaxEnabled(): void;
    get strictMaxEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _strictMinEnabled?;
    get strictMinEnabled(): boolean | cdktf.IResolvable;
    set strictMinEnabled(value: boolean | cdktf.IResolvable);
    resetStrictMinEnabled(): void;
    get strictMinEnabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface DataplexDatascanDataQualitySpecRulesRegexExpectation {
    /**
    * A regular expression the column value is expected to match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#regex DataplexDatascan#regex}
    */
    readonly regex: string;
}
export declare function dataplexDatascanDataQualitySpecRulesRegexExpectationToTerraform(struct?: DataplexDatascanDataQualitySpecRulesRegexExpectationOutputReference | DataplexDatascanDataQualitySpecRulesRegexExpectation): any;
export declare class DataplexDatascanDataQualitySpecRulesRegexExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataQualitySpecRulesRegexExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpecRulesRegexExpectation | undefined);
    private _regex?;
    get regex(): string;
    set regex(value: string);
    get regexInput(): string | undefined;
}
export interface DataplexDatascanDataQualitySpecRulesRowConditionExpectation {
    /**
    * The SQL expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#sql_expression DataplexDatascan#sql_expression}
    */
    readonly sqlExpression: string;
}
export declare function dataplexDatascanDataQualitySpecRulesRowConditionExpectationToTerraform(struct?: DataplexDatascanDataQualitySpecRulesRowConditionExpectationOutputReference | DataplexDatascanDataQualitySpecRulesRowConditionExpectation): any;
export declare class DataplexDatascanDataQualitySpecRulesRowConditionExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataQualitySpecRulesRowConditionExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpecRulesRowConditionExpectation | undefined);
    private _sqlExpression?;
    get sqlExpression(): string;
    set sqlExpression(value: string);
    get sqlExpressionInput(): string | undefined;
}
export interface DataplexDatascanDataQualitySpecRulesSetExpectation {
    /**
    * Expected values for the column value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#values DataplexDatascan#values}
    */
    readonly values: string[];
}
export declare function dataplexDatascanDataQualitySpecRulesSetExpectationToTerraform(struct?: DataplexDatascanDataQualitySpecRulesSetExpectationOutputReference | DataplexDatascanDataQualitySpecRulesSetExpectation): any;
export declare class DataplexDatascanDataQualitySpecRulesSetExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataQualitySpecRulesSetExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpecRulesSetExpectation | undefined);
    private _values?;
    get values(): string[];
    set values(value: string[]);
    get valuesInput(): string[] | undefined;
}
export interface DataplexDatascanDataQualitySpecRulesStatisticRangeExpectation {
    /**
    * The maximum column statistic value allowed for a row to pass this validation.
  At least one of minValue and maxValue need to be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#max_value DataplexDatascan#max_value}
    */
    readonly maxValue?: string;
    /**
    * The minimum column statistic value allowed for a row to pass this validation.
  At least one of minValue and maxValue need to be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#min_value DataplexDatascan#min_value}
    */
    readonly minValue?: string;
    /**
    * column statistics. Possible values: ["STATISTIC_UNDEFINED", "MEAN", "MIN", "MAX"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#statistic DataplexDatascan#statistic}
    */
    readonly statistic: string;
    /**
    * Whether column statistic needs to be strictly lesser than ('<') the maximum, or if equality is allowed.
  Only relevant if a maxValue has been defined. Default = false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#strict_max_enabled DataplexDatascan#strict_max_enabled}
    */
    readonly strictMaxEnabled?: boolean | cdktf.IResolvable;
    /**
    * Whether column statistic needs to be strictly greater than ('>') the minimum, or if equality is allowed.
  Only relevant if a minValue has been defined. Default = false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#strict_min_enabled DataplexDatascan#strict_min_enabled}
    */
    readonly strictMinEnabled?: boolean | cdktf.IResolvable;
}
export declare function dataplexDatascanDataQualitySpecRulesStatisticRangeExpectationToTerraform(struct?: DataplexDatascanDataQualitySpecRulesStatisticRangeExpectationOutputReference | DataplexDatascanDataQualitySpecRulesStatisticRangeExpectation): any;
export declare class DataplexDatascanDataQualitySpecRulesStatisticRangeExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataQualitySpecRulesStatisticRangeExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpecRulesStatisticRangeExpectation | undefined);
    private _maxValue?;
    get maxValue(): string;
    set maxValue(value: string);
    resetMaxValue(): void;
    get maxValueInput(): string | undefined;
    private _minValue?;
    get minValue(): string;
    set minValue(value: string);
    resetMinValue(): void;
    get minValueInput(): string | undefined;
    private _statistic?;
    get statistic(): string;
    set statistic(value: string);
    get statisticInput(): string | undefined;
    private _strictMaxEnabled?;
    get strictMaxEnabled(): boolean | cdktf.IResolvable;
    set strictMaxEnabled(value: boolean | cdktf.IResolvable);
    resetStrictMaxEnabled(): void;
    get strictMaxEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _strictMinEnabled?;
    get strictMinEnabled(): boolean | cdktf.IResolvable;
    set strictMinEnabled(value: boolean | cdktf.IResolvable);
    resetStrictMinEnabled(): void;
    get strictMinEnabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface DataplexDatascanDataQualitySpecRulesTableConditionExpectation {
    /**
    * The SQL expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#sql_expression DataplexDatascan#sql_expression}
    */
    readonly sqlExpression: string;
}
export declare function dataplexDatascanDataQualitySpecRulesTableConditionExpectationToTerraform(struct?: DataplexDatascanDataQualitySpecRulesTableConditionExpectationOutputReference | DataplexDatascanDataQualitySpecRulesTableConditionExpectation): any;
export declare class DataplexDatascanDataQualitySpecRulesTableConditionExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataQualitySpecRulesTableConditionExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpecRulesTableConditionExpectation | undefined);
    private _sqlExpression?;
    get sqlExpression(): string;
    set sqlExpression(value: string);
    get sqlExpressionInput(): string | undefined;
}
export interface DataplexDatascanDataQualitySpecRulesUniquenessExpectation {
}
export declare function dataplexDatascanDataQualitySpecRulesUniquenessExpectationToTerraform(struct?: DataplexDatascanDataQualitySpecRulesUniquenessExpectationOutputReference | DataplexDatascanDataQualitySpecRulesUniquenessExpectation): any;
export declare class DataplexDatascanDataQualitySpecRulesUniquenessExpectationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataQualitySpecRulesUniquenessExpectation | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpecRulesUniquenessExpectation | undefined);
}
export interface DataplexDatascanDataQualitySpecRules {
    /**
    * The unnested column which this rule is evaluated against.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#column DataplexDatascan#column}
    */
    readonly column?: string;
    /**
    * The dimension a rule belongs to. Results are also aggregated at the dimension level. Supported dimensions are ["COMPLETENESS", "ACCURACY", "CONSISTENCY", "VALIDITY", "UNIQUENESS", "INTEGRITY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#dimension DataplexDatascan#dimension}
    */
    readonly dimension: string;
    /**
    * Rows with null values will automatically fail a rule, unless ignoreNull is true. In that case, such null rows are trivially considered passing. Only applicable to ColumnMap rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#ignore_null DataplexDatascan#ignore_null}
    */
    readonly ignoreNull?: boolean | cdktf.IResolvable;
    /**
    * The minimum ratio of passing_rows / total_rows required to pass this rule, with a range of [0.0, 1.0]. 0 indicates default value (i.e. 1.0).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#threshold DataplexDatascan#threshold}
    */
    readonly threshold?: number;
    /**
    * non_null_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#non_null_expectation DataplexDatascan#non_null_expectation}
    */
    readonly nonNullExpectation?: DataplexDatascanDataQualitySpecRulesNonNullExpectation;
    /**
    * range_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#range_expectation DataplexDatascan#range_expectation}
    */
    readonly rangeExpectation?: DataplexDatascanDataQualitySpecRulesRangeExpectation;
    /**
    * regex_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#regex_expectation DataplexDatascan#regex_expectation}
    */
    readonly regexExpectation?: DataplexDatascanDataQualitySpecRulesRegexExpectation;
    /**
    * row_condition_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#row_condition_expectation DataplexDatascan#row_condition_expectation}
    */
    readonly rowConditionExpectation?: DataplexDatascanDataQualitySpecRulesRowConditionExpectation;
    /**
    * set_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#set_expectation DataplexDatascan#set_expectation}
    */
    readonly setExpectation?: DataplexDatascanDataQualitySpecRulesSetExpectation;
    /**
    * statistic_range_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#statistic_range_expectation DataplexDatascan#statistic_range_expectation}
    */
    readonly statisticRangeExpectation?: DataplexDatascanDataQualitySpecRulesStatisticRangeExpectation;
    /**
    * table_condition_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#table_condition_expectation DataplexDatascan#table_condition_expectation}
    */
    readonly tableConditionExpectation?: DataplexDatascanDataQualitySpecRulesTableConditionExpectation;
    /**
    * uniqueness_expectation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#uniqueness_expectation DataplexDatascan#uniqueness_expectation}
    */
    readonly uniquenessExpectation?: DataplexDatascanDataQualitySpecRulesUniquenessExpectation;
}
export declare function dataplexDatascanDataQualitySpecRulesToTerraform(struct?: DataplexDatascanDataQualitySpecRules | cdktf.IResolvable): any;
export declare class DataplexDatascanDataQualitySpecRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataplexDatascanDataQualitySpecRules | cdktf.IResolvable | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpecRules | cdktf.IResolvable | undefined);
    private _column?;
    get column(): string;
    set column(value: string);
    resetColumn(): void;
    get columnInput(): string | undefined;
    private _dimension?;
    get dimension(): string;
    set dimension(value: string);
    get dimensionInput(): string | undefined;
    private _ignoreNull?;
    get ignoreNull(): boolean | cdktf.IResolvable;
    set ignoreNull(value: boolean | cdktf.IResolvable);
    resetIgnoreNull(): void;
    get ignoreNullInput(): boolean | cdktf.IResolvable | undefined;
    private _threshold?;
    get threshold(): number;
    set threshold(value: number);
    resetThreshold(): void;
    get thresholdInput(): number | undefined;
    private _nonNullExpectation;
    get nonNullExpectation(): DataplexDatascanDataQualitySpecRulesNonNullExpectationOutputReference;
    putNonNullExpectation(value: DataplexDatascanDataQualitySpecRulesNonNullExpectation): void;
    resetNonNullExpectation(): void;
    get nonNullExpectationInput(): DataplexDatascanDataQualitySpecRulesNonNullExpectation | undefined;
    private _rangeExpectation;
    get rangeExpectation(): DataplexDatascanDataQualitySpecRulesRangeExpectationOutputReference;
    putRangeExpectation(value: DataplexDatascanDataQualitySpecRulesRangeExpectation): void;
    resetRangeExpectation(): void;
    get rangeExpectationInput(): DataplexDatascanDataQualitySpecRulesRangeExpectation | undefined;
    private _regexExpectation;
    get regexExpectation(): DataplexDatascanDataQualitySpecRulesRegexExpectationOutputReference;
    putRegexExpectation(value: DataplexDatascanDataQualitySpecRulesRegexExpectation): void;
    resetRegexExpectation(): void;
    get regexExpectationInput(): DataplexDatascanDataQualitySpecRulesRegexExpectation | undefined;
    private _rowConditionExpectation;
    get rowConditionExpectation(): DataplexDatascanDataQualitySpecRulesRowConditionExpectationOutputReference;
    putRowConditionExpectation(value: DataplexDatascanDataQualitySpecRulesRowConditionExpectation): void;
    resetRowConditionExpectation(): void;
    get rowConditionExpectationInput(): DataplexDatascanDataQualitySpecRulesRowConditionExpectation | undefined;
    private _setExpectation;
    get setExpectation(): DataplexDatascanDataQualitySpecRulesSetExpectationOutputReference;
    putSetExpectation(value: DataplexDatascanDataQualitySpecRulesSetExpectation): void;
    resetSetExpectation(): void;
    get setExpectationInput(): DataplexDatascanDataQualitySpecRulesSetExpectation | undefined;
    private _statisticRangeExpectation;
    get statisticRangeExpectation(): DataplexDatascanDataQualitySpecRulesStatisticRangeExpectationOutputReference;
    putStatisticRangeExpectation(value: DataplexDatascanDataQualitySpecRulesStatisticRangeExpectation): void;
    resetStatisticRangeExpectation(): void;
    get statisticRangeExpectationInput(): DataplexDatascanDataQualitySpecRulesStatisticRangeExpectation | undefined;
    private _tableConditionExpectation;
    get tableConditionExpectation(): DataplexDatascanDataQualitySpecRulesTableConditionExpectationOutputReference;
    putTableConditionExpectation(value: DataplexDatascanDataQualitySpecRulesTableConditionExpectation): void;
    resetTableConditionExpectation(): void;
    get tableConditionExpectationInput(): DataplexDatascanDataQualitySpecRulesTableConditionExpectation | undefined;
    private _uniquenessExpectation;
    get uniquenessExpectation(): DataplexDatascanDataQualitySpecRulesUniquenessExpectationOutputReference;
    putUniquenessExpectation(value: DataplexDatascanDataQualitySpecRulesUniquenessExpectation): void;
    resetUniquenessExpectation(): void;
    get uniquenessExpectationInput(): DataplexDatascanDataQualitySpecRulesUniquenessExpectation | undefined;
}
export declare class DataplexDatascanDataQualitySpecRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataplexDatascanDataQualitySpecRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataplexDatascanDataQualitySpecRulesOutputReference;
}
export interface DataplexDatascanDataQualitySpec {
    /**
    * A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in BigQuery standard SQL syntax. Example: col1 >= 0 AND col2 < 10
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#row_filter DataplexDatascan#row_filter}
    */
    readonly rowFilter?: string;
    /**
    * The percentage of the records to be selected from the dataset for DataScan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#sampling_percent DataplexDatascan#sampling_percent}
    */
    readonly samplingPercent?: number;
    /**
    * rules block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#rules DataplexDatascan#rules}
    */
    readonly rules?: DataplexDatascanDataQualitySpecRules[] | cdktf.IResolvable;
}
export declare function dataplexDatascanDataQualitySpecToTerraform(struct?: DataplexDatascanDataQualitySpecOutputReference | DataplexDatascanDataQualitySpec): any;
export declare class DataplexDatascanDataQualitySpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanDataQualitySpec | undefined;
    set internalValue(value: DataplexDatascanDataQualitySpec | undefined);
    private _rowFilter?;
    get rowFilter(): string;
    set rowFilter(value: string);
    resetRowFilter(): void;
    get rowFilterInput(): string | undefined;
    private _samplingPercent?;
    get samplingPercent(): number;
    set samplingPercent(value: number);
    resetSamplingPercent(): void;
    get samplingPercentInput(): number | undefined;
    private _rules;
    get rules(): DataplexDatascanDataQualitySpecRulesList;
    putRules(value: DataplexDatascanDataQualitySpecRules[] | cdktf.IResolvable): void;
    resetRules(): void;
    get rulesInput(): cdktf.IResolvable | DataplexDatascanDataQualitySpecRules[] | undefined;
}
export interface DataplexDatascanExecutionSpecTriggerOnDemand {
}
export declare function dataplexDatascanExecutionSpecTriggerOnDemandToTerraform(struct?: DataplexDatascanExecutionSpecTriggerOnDemandOutputReference | DataplexDatascanExecutionSpecTriggerOnDemand): any;
export declare class DataplexDatascanExecutionSpecTriggerOnDemandOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanExecutionSpecTriggerOnDemand | undefined;
    set internalValue(value: DataplexDatascanExecutionSpecTriggerOnDemand | undefined);
}
export interface DataplexDatascanExecutionSpecTriggerSchedule {
    /**
    * Cron schedule for running scans periodically. This field is required for Schedule scans.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#cron DataplexDatascan#cron}
    */
    readonly cron: string;
}
export declare function dataplexDatascanExecutionSpecTriggerScheduleToTerraform(struct?: DataplexDatascanExecutionSpecTriggerScheduleOutputReference | DataplexDatascanExecutionSpecTriggerSchedule): any;
export declare class DataplexDatascanExecutionSpecTriggerScheduleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanExecutionSpecTriggerSchedule | undefined;
    set internalValue(value: DataplexDatascanExecutionSpecTriggerSchedule | undefined);
    private _cron?;
    get cron(): string;
    set cron(value: string);
    get cronInput(): string | undefined;
}
export interface DataplexDatascanExecutionSpecTrigger {
    /**
    * on_demand block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#on_demand DataplexDatascan#on_demand}
    */
    readonly onDemand?: DataplexDatascanExecutionSpecTriggerOnDemand;
    /**
    * schedule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#schedule DataplexDatascan#schedule}
    */
    readonly schedule?: DataplexDatascanExecutionSpecTriggerSchedule;
}
export declare function dataplexDatascanExecutionSpecTriggerToTerraform(struct?: DataplexDatascanExecutionSpecTriggerOutputReference | DataplexDatascanExecutionSpecTrigger): any;
export declare class DataplexDatascanExecutionSpecTriggerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanExecutionSpecTrigger | undefined;
    set internalValue(value: DataplexDatascanExecutionSpecTrigger | undefined);
    private _onDemand;
    get onDemand(): DataplexDatascanExecutionSpecTriggerOnDemandOutputReference;
    putOnDemand(value: DataplexDatascanExecutionSpecTriggerOnDemand): void;
    resetOnDemand(): void;
    get onDemandInput(): DataplexDatascanExecutionSpecTriggerOnDemand | undefined;
    private _schedule;
    get schedule(): DataplexDatascanExecutionSpecTriggerScheduleOutputReference;
    putSchedule(value: DataplexDatascanExecutionSpecTriggerSchedule): void;
    resetSchedule(): void;
    get scheduleInput(): DataplexDatascanExecutionSpecTriggerSchedule | undefined;
}
export interface DataplexDatascanExecutionSpec {
    /**
    * The unnested field (of type Date or Timestamp) that contains values which monotonically increase over time. If not specified, a data scan will run for all data in the table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#field DataplexDatascan#field}
    */
    readonly field?: string;
    /**
    * trigger block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#trigger DataplexDatascan#trigger}
    */
    readonly trigger: DataplexDatascanExecutionSpecTrigger;
}
export declare function dataplexDatascanExecutionSpecToTerraform(struct?: DataplexDatascanExecutionSpecOutputReference | DataplexDatascanExecutionSpec): any;
export declare class DataplexDatascanExecutionSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanExecutionSpec | undefined;
    set internalValue(value: DataplexDatascanExecutionSpec | undefined);
    private _field?;
    get field(): string;
    set field(value: string);
    resetField(): void;
    get fieldInput(): string | undefined;
    private _trigger;
    get trigger(): DataplexDatascanExecutionSpecTriggerOutputReference;
    putTrigger(value: DataplexDatascanExecutionSpecTrigger): void;
    get triggerInput(): DataplexDatascanExecutionSpecTrigger | undefined;
}
export interface DataplexDatascanTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#create DataplexDatascan#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#delete DataplexDatascan#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan#update DataplexDatascan#update}
    */
    readonly update?: string;
}
export declare function dataplexDatascanTimeoutsToTerraform(struct?: DataplexDatascanTimeouts | cdktf.IResolvable): any;
export declare class DataplexDatascanTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexDatascanTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataplexDatascanTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan google_dataplex_datascan}
*/
export declare class DataplexDatascan extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dataplex_datascan";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.70.0/docs/resources/dataplex_datascan google_dataplex_datascan} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataplexDatascanConfig
    */
    constructor(scope: Construct, id: string, config: DataplexDatascanConfig);
    get createTime(): string;
    private _dataProfileResult;
    get dataProfileResult(): DataplexDatascanDataProfileResultList;
    private _dataQualityResult;
    get dataQualityResult(): DataplexDatascanDataQualityResultList;
    private _dataScanId?;
    get dataScanId(): string;
    set dataScanId(value: string);
    get dataScanIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _executionStatus;
    get executionStatus(): DataplexDatascanExecutionStatusList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    get type(): string;
    get uid(): string;
    get updateTime(): string;
    private _data;
    get data(): DataplexDatascanDataOutputReference;
    putData(value: DataplexDatascanData): void;
    get dataInput(): DataplexDatascanData | undefined;
    private _dataProfileSpec;
    get dataProfileSpec(): DataplexDatascanDataProfileSpecOutputReference;
    putDataProfileSpec(value: DataplexDatascanDataProfileSpec): void;
    resetDataProfileSpec(): void;
    get dataProfileSpecInput(): DataplexDatascanDataProfileSpec | undefined;
    private _dataQualitySpec;
    get dataQualitySpec(): DataplexDatascanDataQualitySpecOutputReference;
    putDataQualitySpec(value: DataplexDatascanDataQualitySpec): void;
    resetDataQualitySpec(): void;
    get dataQualitySpecInput(): DataplexDatascanDataQualitySpec | undefined;
    private _executionSpec;
    get executionSpec(): DataplexDatascanExecutionSpecOutputReference;
    putExecutionSpec(value: DataplexDatascanExecutionSpec): void;
    get executionSpecInput(): DataplexDatascanExecutionSpec | undefined;
    private _timeouts;
    get timeouts(): DataplexDatascanTimeoutsOutputReference;
    putTimeouts(value: DataplexDatascanTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataplexDatascanTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
